@@ -6,12 +6,10 @@ import org.apache.spark.sql.types.StructType
 
 object SQLUtils {
   def createDataFrame(
-    sc: org.apache.spark.sql.SparkSession,
+    sc: org.apache.spark.sql.SQLContext,
     catalystRows: RDD[InternalRow],
     schema: StructType
   ): DataFrame = {
-    val sdf = sc.internalCreateDataFrame(catalystRows, schema)
-
-    sdf
+    sc.internalCreateDataFrame(catalystRows, schema)
   }
 }
